aboutsummaryrefslogtreecommitdiff
path: root/internal/filedesc/build_test.go
diff options
context:
space:
mode:
Diffstat (limited to 'internal/filedesc/build_test.go')
-rw-r--r--internal/filedesc/build_test.go4
1 files changed, 3 insertions, 1 deletions
diff --git a/internal/filedesc/build_test.go b/internal/filedesc/build_test.go
index f8007a04..979b8ea1 100644
--- a/internal/filedesc/build_test.go
+++ b/internal/filedesc/build_test.go
@@ -53,13 +53,15 @@ func TestInit(t *testing.T) {
// The protoreflect descriptors don't include source info.
descPkg.Append("FileDescriptorProto.source_code_info"): true,
descPkg.Append("FileDescriptorProto.syntax"): true,
+ // Nothing is using edition yet.
+ descPkg.Append("FileDescriptorProto.edition"): true,
// Impossible to test proto3 optional in a proto2 file.
descPkg.Append("FieldDescriptorProto.proto3_optional"): true,
// TODO: Test oneof and extension options. Testing these requires extending the
// options messages (because they contain no user-settable fields), but importing
// decriptor.proto from test.proto currently causes an import cycle. Add test
// cases when that import cycle has been fixed.
descPkg.Append("OneofDescriptorProto.options"): true,
}
@@ -53,13 +53,15 @@ func TestInit(t *testing.T) {
// TODO: Test oneof and extension options. Testing these requires extending the
// options messages (because they contain no user-settable fields), but importing
- // decriptor.proto from test.proto currently causes an import cycle. Add test
+ // descriptor.proto from test.proto currently causes an import cycle. Add test
// cases when that import cycle has been fixed.
descPkg.Append("OneofDescriptorProto.options"): true,